@@ -5,9 +5,8 @@
 
 #include "xtext.h"
 
-#define CONF_MAX 29 
 
-static char conf_d[CONF_MAX][40] = {	"MAIN_WINDOW_WIDTH:",
+static char *conf_d[] = {		"MAIN_WINDOW_WIDTH:",
 					"MAIN_WINDOW_HEIGHT:",
 					"MAIN_WINDOW_COLOR:",
 					"MAIN_FONT_COLOR:",
@@ -24,6 +23,9 @@ static char conf_d[CONF_MAX][40] = {	"MAIN_WINDOW_WIDTH:",
 					"ROW_SPACE:",
 					"TITLE_DISP:",
 					"RUBY_DISP:",
+					"PAGE_DISP:",
+					"KINSC_DISP:",
+					"CHUKI_DISP:",
 					"BOOK_DIR:",
 					"RUBI_FONT:",
 					"XFT_FONT:",
@@ -35,7 +37,10 @@ static char conf_d[CONF_MAX][40] = {	"MAIN_WINDOW_WIDTH:",
 					"SIORI_MENU:",
 					"QUIT:",
 					"MENU:",
-					"TITLE_KEY:"	};
+					"TITLE_KEY:",
+					"KINSC_KEY:",
+					"CHUKI_KEY:",
+					"PAGE_KEY:"	};
 
 static int _get_data(char *s,char *t)
 {
@@ -76,6 +81,9 @@ static int _init_xconf(xtext_conf_t *xconf)
 	xconf->anti = -1;
 	xconf->title_on = -1;
 	xconf->ruby_on = -1;
+	xconf->page_on = -1;
+	xconf->kinsc = -1;
+	xconf->chuki = -1;
 	xconf->line_space = -1;
 	xconf->row_space = -1;
 	xconf->page_next[0] = '\0';
@@ -86,6 +94,9 @@ static int _init_xconf(xtext_conf_t *xconf)
 	xconf->quit[0] = '\0';
 	xconf->menu[0] = '\0';
 	xconf->title_key[0] = '\0';
+	xconf->kinsc_key[0] = '\0';
+	xconf->chuki_key[0] = '\0';
+	xconf->page_key[0] = '\0';
 
 	return 0;
 }
@@ -104,7 +115,7 @@ int xtext_conf_data(xtext_conf_t *xconf,xtext_conf_t def)
 
 	while(fgets(buf,256,fp) != NULL){
 		if(buf[0] == '\n' || buf[0] == '#') continue;
-		for(i=0;i<CONF_MAX;i++){
+		for(i=0;i<sizeof(conf_d)/sizeof(char *);i++){
 			len = strlen(conf_d[i]);
 			if(strncmp(buf,conf_d[i],strlen(conf_d[i])) == 0){
 				_get_data(buf+len,temp);
@@ -127,18 +138,24 @@ int xtext_conf_data(xtext_conf_t *xconf,xtext_conf_t def)
 					case 14:xconf->row_space = atoi(temp);break;
 					case 15:xconf->title_on = atoi(temp);break;
 					case 16:xconf->ruby_on = atoi(temp);break;
-					case 17:strcpy(xconf->book_dir,temp);break;
-					case 18:strcpy(xconf->rubi_font,temp);break;
-					case 19:xconf->anti = atoi(temp);break;
-					case 20:strcpy(xconf->rubi_font_color,temp);break;
-					case 21:strcpy(xconf->page_next,temp);break;
-					case 22:strcpy(xconf->page_prev,temp);break;
-					case 23:strcpy(xconf->conf_page,temp);break;
-					case 24:strcpy(xconf->book_mark,temp);break;
-					case 25:strcpy(xconf->siori_menu,temp);break;
-					case 26:strcpy(xconf->quit,temp);break;
-					case 27:strcpy(xconf->menu,temp);break;
-					case 28:strcpy(xconf->title_key,temp);break;
+					case 17:xconf->page_on = atoi(temp);break;
+					case 18:xconf->kinsc = atoi(temp);break;
+					case 19:xconf->chuki = atoi(temp);break;
+					case 20:strcpy(xconf->book_dir,temp);break;
+					case 21:strcpy(xconf->rubi_font,temp);break;
+					case 22:xconf->anti = atoi(temp);break;
+					case 23:strcpy(xconf->rubi_font_color,temp);break;
+					case 24:strcpy(xconf->page_next,temp);break;
+					case 25:strcpy(xconf->page_prev,temp);break;
+					case 26:strcpy(xconf->conf_page,temp);break;
+					case 27:strcpy(xconf->book_mark,temp);break;
+					case 28:strcpy(xconf->siori_menu,temp);break;
+					case 29:strcpy(xconf->quit,temp);break;
+					case 30:strcpy(xconf->menu,temp);break;
+					case 31:strcpy(xconf->title_key,temp);break;
+					case 32:strcpy(xconf->kinsc_key,temp);break;
+					case 33:strcpy(xconf->chuki_key,temp);break;
+					case 34:strcpy(xconf->page_key,temp);break;
 				}
 				break;
 			}
@@ -167,6 +184,9 @@ xtext_def:
 	if(xconf->anti == -1) xconf->anti = def.anti;
 	if(xconf->title_on == -1) xconf->title_on = def.title_on;
 	if(xconf->ruby_on == -1) xconf->ruby_on = def.title_on;
+	if(xconf->page_on == -1) xconf->page_on = def.page_on;
+	if(xconf->kinsc == -1) xconf->kinsc = def.kinsc;
+	if(xconf->chuki == -1) xconf->chuki = def.chuki;
 	if(xconf->line_space == -1) xconf->line_space = def.line_space;
 	if(xconf->row_space == -1) xconf->row_space = def.row_space;
 	if(xconf->page_next[0] == '\0') strcpy(xconf->page_next,def.page_next);
@@ -177,6 +197,9 @@ xtext_def:
 	if(xconf->quit[0] == '\0') strcpy(xconf->quit,def.quit);
 	if(xconf->menu[0] == '\0') strcpy(xconf->menu,def.menu);
 	if(xconf->title_key[0] == '\0') strcpy(xconf->title_key,def.title_key);
+	if(xconf->kinsc_key[0] == '\0') strcpy(xconf->kinsc_key,def.kinsc_key);
+	if(xconf->chuki_key[0] == '\0') strcpy(xconf->chuki_key,def.chuki_key);
+	if(xconf->page_key[0] == '\0') strcpy(xconf->page_key,def.page_key);
 
 	return 0;
 }
@@ -270,6 +293,18 @@ static int _write_conf_data(FILE *fp,char *name,xtext_conf_t *xconf)
 		sprintf(buf,"%s %d",name,xconf->ruby_on);
 		fputs(buf,fp);
 		return strlen(buf);
+	}else if(strcmp("PAGE_DISP:",name) == 0){
+		sprintf(buf,"%s %d",name,xconf->page_on);
+		fputs(buf,fp);
+		return strlen(buf);
+	}else if(strcmp("KINSC_DISP:",name) == 0){
+		sprintf(buf,"%s %d",name,xconf->kinsc);
+		fputs(buf,fp);
+		return strlen(buf);
+	}else if(strcmp("CHUKI_DISP:",name) == 0){
+		sprintf(buf,"%s %d",name,xconf->chuki);
+		fputs(buf,fp);
+		return strlen(buf);
 	}else if(strcmp("BOOK_DIR:",name) == 0){
 		sprintf(buf,"%s %s",name,xconf->book_dir);
 		fputs(buf,fp);
@@ -318,6 +353,18 @@ static int _write_conf_data(FILE *fp,char *name,xtext_conf_t *xconf)
 		sprintf(buf,"%s %s",name,xconf->title_key);
 		fputs(buf,fp);
 		return strlen(buf);
+	}else if(strcmp("KINSC_KEY:",name) == 0){
+		sprintf(buf,"%s %s",name,xconf->kinsc_key);
+		fputs(buf,fp);
+		return strlen(buf);
+	}else if(strcmp("CHUKI_KEY:",name) == 0){
+		sprintf(buf,"%s %s",name,xconf->chuki_key);
+		fputs(buf,fp);
+		return strlen(buf);
+	}else if(strcmp("PAGE_KEY:",name) == 0){
+		sprintf(buf,"%s %s",name,xconf->page_key);
+		fputs(buf,fp);
+		return strlen(buf);
 	}
 
 	return 0;
@@ -328,11 +375,14 @@ int xtext_conf_save(void *data0,int data1)
 	struct passwd *pwd;
 	char conf_file_path[256],temp_file_path[256],buf[256];
 	int i,flag;
+	int CONF_MAX;
 
 	xtext_conf_t *xconf;
 
 	if((xconf = (xtext_conf_t *)data0) == NULL) return -2;
 
+	CONF_MAX = sizeof(conf_d)/sizeof(char *);
+
 	pwd = getpwuid(getuid());
 	sprintf(conf_file_path,"%s/%s/%s",pwd->pw_dir,CONF_DIR_NAME,CONF_FILE_NAME);
 	sprintf(temp_file_path,"%s/%s/%s",pwd->pw_dir,CONF_DIR_NAME,"xtext.conf.temp");
@@ -381,30 +431,3 @@ int xtext_conf_save(void *data0,int data1)
 	return 2;
 }
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
