@@ -194,6 +194,27 @@ int xtextHelpData2Sub(sub_window_t **head,sub_window_t **tail,xtext_conf_t *xcon
 	type = XJP_CHA;
 	_subwindow_data_insert(head,tail,line_str,line_data,NULL,xtext_conf_change,data0,data1,type,i++);
 
+	strcpy(line_str,"ǡɽON-OFF:");
+	line_data = xconf->page_key;
+	data0 = (char *)xconf->page_key;
+	data1 = XJP_CHA;
+	type = XJP_CHA;
+	_subwindow_data_insert(head,tail,line_str,line_data,NULL,xtext_conf_change,data0,data1,type,i++);
+
+	strcpy(line_str,"٥ѹ:");
+	line_data = xconf->kinsc_key;
+	data0 = (char *)xconf->kinsc_key;
+	data1 = XJP_CHA;
+	type = XJP_CHA;
+	_subwindow_data_insert(head,tail,line_str,line_data,NULL,xtext_conf_change,data0,data1,type,i++);
+
+	strcpy(line_str,"ɥON-OFF:");
+	line_data = xconf->chuki_key;
+	data0 = (char *)xconf->chuki_key;
+	data1 = XJP_CHA;
+	type = XJP_CHA;
+	_subwindow_data_insert(head,tail,line_str,line_data,NULL,xtext_conf_change,data0,data1,type,i++);
+
 	strcpy(line_str,"[ɥ]");
 	line_data = NULL;
 	data0 = NULL;
@@ -277,6 +298,12 @@ int xtextHelpData2Sub(sub_window_t **head,sub_window_t **tail,xtext_conf_t *xcon
 	data1 = XJP_COL;
 	type = XJP_COL;
 	_subwindow_data_insert(head,tail,line_str,line_data,NULL,xtext_conf_change,data0,data1,type,i++);
+	strcpy(line_str,"[ե]");
+	line_data = NULL;
+	data0 = NULL;
+	data1 = XJP_NONE;
+	type = XJP_NONE;
+	_subwindow_data_insert(head,tail,line_str,line_data,NULL,NULL,data0,data1,type,i++);
 
 	strcpy(line_str,"ե(J):");
 	line_data = xconf->main_font_j;
@@ -320,6 +347,13 @@ int xtextHelpData2Sub(sub_window_t **head,sub_window_t **tail,xtext_conf_t *xcon
 	type = XJP_INT;
 	_subwindow_data_insert(head,tail,line_str,line_data,NULL,xtext_conf_change,data0,data1,type,i++);
 
+	strcpy(line_str,"[]");
+	line_data = NULL;
+	data0 = NULL;
+	data1 = XJP_NONE;
+	type = XJP_NONE;
+	_subwindow_data_insert(head,tail,line_str,line_data,NULL,NULL,data0,data1,type,i++);
+
 	strcpy(line_str,"ꥢ:");
 	line_data = (int *)&xconf->anti;
 	data0 = (int *)&xconf->anti;
@@ -334,6 +368,27 @@ int xtextHelpData2Sub(sub_window_t **head,sub_window_t **tail,xtext_conf_t *xcon
 	type = XJP_INT;
 	_subwindow_data_insert(head,tail,line_str,line_data,NULL,xtext_conf_change,data0,data1,type,i++);
 
+	strcpy(line_str,"ǡɽ:");
+	line_data = (int *)&xconf->page_on;
+	data0 = (int *)&xconf->page_on;
+	data1 = XJP_INT;
+	type = XJP_INT;
+	_subwindow_data_insert(head,tail,line_str,line_data,NULL,xtext_conf_change,data0,data1,type,i++);
+
+	strcpy(line_str,"٥:");
+	line_data = (int *)&xconf->kinsc;
+	data0 = (int *)&xconf->kinsc;
+	data1 = XJP_INT;
+	type = XJP_INT;
+	_subwindow_data_insert(head,tail,line_str,line_data,NULL,xtext_conf_change,data0,data1,type,i++);
+
+	strcpy(line_str,"ɥɽ:");
+	line_data = (int *)&xconf->chuki;
+	data0 = (int *)&xconf->chuki;
+	data1 = XJP_INT;
+	type = XJP_INT;
+	_subwindow_data_insert(head,tail,line_str,line_data,NULL,xtext_conf_change,data0,data1,type,i++);
+
 	/*
 	strcpy(line_str,"ɽ:");
 	line_data = (int *)&xconf->ruby_on;
@@ -385,18 +440,24 @@ int xtextBookData2Sub(sub_window_t **head,sub_window_t **tail,char *dname)
 	total = ibookGetFileData(&bhead,&btail,dname);
 
 	_subwindow_data_insert(head,tail,"----- [Up-Donw]ư [Enter] -----",NULL,NULL,NULL,NULL,XJP_NONE,XJP_NONE,1);
+
 	_subwindow_data_insert(head,tail,"(󥻥)",NULL,NULL,xtext_conf_quit,(char *)XJP_CANCEL,XJP_NONE,XJP_NONE,2);
+
 	for(ib=bhead,i=3;ib!=NULL;ib=ib->next,i++){
-		sw = (sub_window_t *)_subwindow_data_alloc();
-
-		sprintf(sw->line_str,"%s (%s)",ib->title,ib->filename);
-		sw->re_str = (char *)malloc(strlen(ib->fullpath)+2);
-		strcpy(sw->re_str,ib->fullpath);
-		sw->func_data1 = XJP_STR;
-		sw->line_no = i;
-
-		_subwindow_data_add(head,tail,sw);
+		/*
+		if(ib->code == -2){
+			_subwindow_data_insert(head,tail,ib->title,NULL,NULL,_select_book_data,ib->fullpath,XJP_NONE,XJP_NONE,i);
 
+		}else{
+		*/
+			sw = (sub_window_t *)_subwindow_data_alloc();
+			sprintf(sw->line_str,"%s (%s)",ib->title,ib->filename);
+			sw->re_str = (char *)malloc(strlen(ib->fullpath)+2);
+			strcpy(sw->re_str,ib->fullpath);
+			sw->func_data1 = XJP_STR;
+			sw->line_no = i;
+			_subwindow_data_add(head,tail,sw);
+		/*}*/
 	}
 	book_link_free(&bhead,&btail);
 
