@@ -6,6 +6,8 @@
 int CHAR_HEADER = 3;
 int CHAR_FOOTER = 3;
 
+XImage *bimg;
+
 
 static void * _page_data_free(page_data_t **start,page_data_t **end)
 {
@@ -348,7 +350,7 @@ static Pixmap _xtext_Draw_imageString_anti(	Display *disp,
 #endif
 
 }
-static XImage * get_string_image(      Display *disp,
+static XImage * get_string_image(      	Display *disp,
                                 	my_window_t *win,
 					char_data_t *char_d,
 					ITEXT_T *it,
@@ -414,6 +416,71 @@ fprintf(stderr,"image END\n");
 
         return base_im;
 }
+static XImage * _xtext_get_bimage(Display *disp,my_window_t *win,char_data_t *char_d)
+{
+	iconv_t con;
+	Pixmap pix;
+	XImage *base_im,*im,*bim;
+	unsigned long pixel;
+	unsigned int c1 = 0xa1,c2 = 0xa2;
+
+	ITEXT_T *it;
+
+	int charSize;
+	int x,y,w,h;
+	int xmin=9999,xmax=0,ymin=9999,ymax=0;
+	unsigned char p[3];
+
+	con = iconv_open("UTF-8","EUC-JP");
+	p[0] = c1;p[1] = c2;p[2] = '\0';
+
+	it = (ITEXT_T *)malloc(sizeof(ITEXT_T));
+	it->c1 = c1;
+	it->c2 = c2;
+	it->utf8 = euc2utf8(con,p,strlen(p));
+	it->ej = 1;
+	it->chu = 0;
+	it->small = 0;
+	it->x_off = 0;
+	it->y_off = 0;
+
+	iconv_close(con);
+
+
+	if(win->anti == 0){
+		pix = _xtext_Draw_imageString_normal(disp,win,char_d,it,1,&base_im);
+
+	}else{
+		pix = _xtext_Draw_imageString_anti(disp,win,char_d,it,1,&base_im);
+	}
+
+	charSize = char_d->charSize;
+        im = XGetImage(disp,pix,0,0,charSize,charSize,0xFFFF,XYPixmap);
+
+        for(x=0;x<charSize;x++){
+                for(y=0;y<charSize;y++){
+                        pixel = XGetPixel(im,x,y);
+                        if(win->bg_pixel != pixel){
+                                if(x < xmin) xmin = x;
+                                if(x > xmax) xmax = x;
+                                if(y < ymin) ymin = y;
+                                if(y > ymax) ymax = y;
+                        }
+                }
+        }
+
+	if((w = xmax - xmin) < 0) return NULL;
+	if((h = ymax - ymin) < 0) return NULL;
+        bim = XGetImage(disp,pix,xmin-1,ymin-1,w+2,h+2,0xFFFF,XYPixmap);
+
+	free(it->utf8);
+	free(it);
+        if(im) XDestroyImage(im);
+	if(base_im) XDestroyImage(base_im);
+        if(pix) XFreePixmap(disp,pix);
+
+	return bim;
+}
 static void * _image_data_insert(Display *disp,my_window_t *win,char_data_t *char_d,ITEXT_T *it,int type)
 {
 	image_data_t *im;
@@ -588,9 +655,6 @@ int xtext_Init_Text(Display *disp,my_window_t *win,IBUF_T *l_head,char_data_t *c
 
 	KINSOKU = win->kinsc;
 
-#if debug
-fprintf(stderr,"ANTI : %d\n",win->anti);
-#endif
 
 	if(win->anti == 0){
 		_xtext_get_normalfont_size(win,&charSize,&charSize_s,&charSize_e,&charSize_r);
@@ -599,21 +663,17 @@ fprintf(stderr,"ANTI : %d\n",win->anti);
 		_xtext_get_antifont_size(disp,win,&charSize,&charSize_s,&charSize_e,&charSize_r);
 	}
 
-
-#if debug
-fprintf(stderr,"size : %d size_s %d size_e %d : size_r %d\n",charSize,charSize_s,charSize_e,charSize_r);
-fprintf(stderr,"Get CharSize End\n");
-#endif
-
 	ct->charSize = charSize;
 	ct->charSize_s = charSize_s;
 	ct->charSize_e = charSize_e;
 	ct->charSize_r = charSize_r;
 
-
 	if(ct->im_head != NULL) _image_data_free(&ct->im_head,&ct->im_tail);
 	if(ct->head != NULL) _page_data_free(&ct->head,&ct->tail);
 
+	if(bimg) XDestroyImage(bimg);
+	bimg = (XImage *)_xtext_get_bimage(disp,win,ct);
+
 	xpad = ct->xpad;
 
 	one_line = charSize + xpad + charSize_r;
@@ -663,9 +723,5 @@ fprintf(stderr,"Get CharSize End\n");
 	}
 	ct->book->total_page = total_page;
 
-#if debug
-fprintf(stderr,"Get Total_Page %d\n",total_page);
-#endif
-
 	return total_page;
 }
